/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Preparation of respondent data (00-1_respondents.do), 
* executed by data preparation master 00_preparation.do
* 
* We proceed in two steps
* I) Generate ISCED variable for panel respondents in Wave 2 (carry forward values from first wave)
* II) Prepare respondent-level data:
*	0) Age, birth date, gender (etc.)
*	1) educational level (based on ISCED)
* 	2) health status (limitations in "activities of daily living")
*	3) employment data (retirement, fulltime employment, working hours)
*	4) marital status
*	5) wave indicator (wave 1 and 2)
*	6) reconstruct a variable for individuals' response status at wave 2 (not provided in wave 2)
*	7) survival state (dead or alive) of wave 1 respondents at wave 2

* Produces data output in temporary folder: 
* - Wave 1: 00-1_respondents_wave1.dta
* - Wave 2: 00-1_respondents_wave2.dta
* 
**********************************************************************/

****************************************************************
* I) Generate ISCED variable for panel respondents in Wave 2 
* (not generated for most wave1 participants in wave2!)
****************************************************************
* 1) merge isced variables from both waves
use mergeid isced_r using "${wave1}/sharew1_${rel}_gv_isced.dta", clear
rename isced_r isced_r_1
gen wave_1 = 1
merge 1:1 mergeid using "${wave2}/sharew2_${rel}_gv_isced.dta", keepusing(isced_r)
rename isced_r isced_r_2
* 2) correct isced values for two wave participants (use inforomation from other wave if missing)
* replace missing isced of wave 1 by non-missing isced of wave 2
replace isced_r_1 = isced_r_2 if mi(isced_r_1) & !mi(isced_r_2) & _merge==3
* replace missing isced of wave 2 by non-missing isced of wave 1
replace isced_r_2 = isced_r_1 if mi(isced_r_2) & !mi(isced_r_1) & _merge==3
gen wave_2 = 2 if inlist(_merge,2,3)
drop _merge
reshape long wave_ isced_r_, i(mergeid) j(j)
drop if wave_==.
drop j 
rename isced_r_ isced_r
rename wave_ wave
* temporarily save wave files
tempfile iscedw1 iscedw2
preserve 
	keep if wave == 1
	drop wave
	save `iscedw1'
restore 
preserve 
	keep if wave == 2
	drop wave
	save `iscedw2'
restore 

clear

**********************************************************
*
* II) Prepare respondent data 
* (foreach wave separately by loop)
* 
* Generate additional variables: 
* age (at int), ISCED (corrected version), health status (ADL),
* marital status, simple wave variable (wave = 1/2), 
* responding status (reconstructed for wave 2),
* dead or alive in wave 2,
* employment: 
*	a) "jobhrs": real job hours (sum of hours for primary and secondary job; top-coded to 24*7; 0 for not employed)
*   b) "ft":     dummy indicator for fulltime work (1 if jobhours >= fulltime threshold defined in config.do)
* 
**********************************************************
* loop over wave-specific files
foreach wave of numlist 1/2 {

log on dataselection
di as txt "**********************************************"
di as txt "Preparing respondents_wave`wave'"
di as txt "**********************************************"
log off dataselection

* for some variables there is a suffix in wave 2
if `wave'==2 local suffix "_w2" 

* respondent file of wave `wave'
use "${wave`wave'}/sharew`wave'_${rel}_cv_r", clear

* check uniquness of identifiers
isid hhid`wave' cvid

* recode missing values
sharetom *


**
* count number of individuals/households
**
log on dataselection
* number of individuals
count
* Number of unique househoulds
distinct hhid`wave'
log off dataselection

**
* Prepare basic variables
**

* 0.) Age
* interview date
gen idate = ym(int_year`suffix', int_month`suffix') 
replace mobirth=7 if mi(mobirth)
gen birthd = ym(yrbirth, mobirth)
gen age = floor((idate - birthd)/12)
drop mobirth birthd int_year`suffix' int_month`suffix'

* 1.) ISCED (educational level)
* merge corrected ISCED variable
merge n:1 mergeid using "`iscedw`wave''", keepusing(isced_r) keep(master matched) nogen
* recode missing values
sharetom isced_r
* recode "still in school" and "other" to missing values
recode isced_r (95 97 = .)

* 2.) Health Status
merge 1:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_gv_health", keepusing(adl2) keep(master matched) nogen
* recode missing values
sharetom adl2

* 3.) Employment

/**
Notes: 

Item on employment state slightly changed from wave 1 to wave 2

ep005
Wave1:
1. Retired
2. Employed or self-employed (including working for family business)
3. Unemployed
4. Permanently sick or disabled
5. Homemaker
97. Other (specify)

Change to in wave2:
1. Retired
2. Employed or self-employed (including working for family business)
3. Unemployed and looking for work
4. Permanently sick or disabled
5. Homemaker
97. Other (Rentier, Living off own property, Student, Doing voluntary work)


EP012: CONTRACTED HOURS PER WEEK IN THIS JOB
In wave 2, a check was added.
CHK: EP012_TotContractHours < 71 MAIN "^FLError[28]"

EP013: TOTAL HOURS WORKED PER WEEK
In wave 2, a check was added.
CHK: EP013_TotWorkedHours < 71 MAIN "^FLError[28]"
	
EP321_ TOTAL HOURS WORKED PER WEEK SECOND JOB

**/

* preparation of employment variables must consider specifities of waves 

* Job data (different by wave)
if `wave' == 1 {
	merge 1:1 hhid`wave' cvid  using "${wave`wave'}/sharew`wave'_${rel}_ep", keepusing(ep005_ ep006_ ep009_1 ep009_2 ep011_1 ep011_2 ep012_1 ep012_2 ep013_1 ep013_2) keep(master matched) nogen
	* recode missing values
	sharetom ep005_ ep006_ ep009_1 ep009_2 ep011_1 ep011_2 ep012_1 ep012_2 ep013_1 ep013_2
	
	* calculate total hours spend per week in jobs 
	clonevar job1hrs = ep013_1
	clonevar job2hrs = ep013_2 
	
	* if there set missing hours to zero
	replace job1hrs = 0 if job1hrs == .
	replace job2hrs = 0 if job2hrs == .
	
	gen jobhrs = job1hrs + job2hrs
	* topcode total working hours to max 24*7
	replace jobhrs = 24*7 if !mi(jobhrs) & jobhrs > 24*7 
	lab var jobhrs "Total real working hours p. week"
}

if `wave' == 2 {
	merge 1:1 hhid`wave' cvid  using "${wave`wave'}/sharew`wave'_${rel}_ep", keepusing(ep005_ ep006_ ep009_ ep011_ ep012_ ep013_ ep321_) keep(master matched) nogen
	sharetom ep005_ ep006_ ep009_ ep011_ ep012_ ep013_ ep321_
	* calculate total hours spend per week in jobs 
	clonevar job1hrs = ep013_
	clonevar job2hrs = ep321_ 
	* if there set missing hours to zero
	replace job1hrs = 0 if job1hrs == .
	replace job2hrs = 0 if job2hrs == .
	* 
	gen jobhrs = job1hrs + job2hrs
	* topcode total working hours to max 24*7
	replace jobhrs = 24*7 if !mi(jobhrs) & jobhrs > 24*7 
	lab var jobhrs "Total real working hours p. week"
}

* generate a dummy indicating fulltime working
gen ft = .
* ft information only for employed or self-employed respondents
replace ft = (jobhrs >= ${fulltime}) if ep005_==2 	// cut-off point $fulltime is defined in config.do
lab var ft "working fulltime (real working hours >=${fulltime} & ep005_==2)"

* 4) Marital state
merge n:1 mergeid using "${wave`wave'}/sharew`wave'_${rel}_dn", keepusing(dn014_) keep(master matched) nogen
sharetom dn014_

* 5) generate a simple wave indicator
gen wave = `wave'
order wave, after(country)

* 6) reconstructing status variables for wave 2 
* note: in wave 2 the variable "status" for identifying respondents is missing (why ???)
* workaround: re-construct status variable by responses to demography module
if `wave'==2 {
	merge 1:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_dn", assert(master match) keepusing(cvid)
	gen status = 1 if _merge==3 // status "respondent"
	drop _merge
}

* 7) respondent of w1 dead of alive in w2
if `wave' == 1 {
	merge 1:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_gv_dol", assert(master matched) keep(master matched) keepusing(deadoralive) nogen
}
isid hhid`wave' cvid

capt drop _merge
* save wave data
save "${tempDir}/00-1_respondents_wave`wave'", replace
}



