/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
* 
* Preparation of couples data (00-4_couples.do), 
* executed by data preparation master 00_preparation.do

* Requires prepared respondent files (prepared in 00-1_respondents.do) as input. 
* 
* Rules and steps: 
* 1) Starting with respondent data, keep only respondents with responding partners in a household
* 2) Select family respondent uniquely and drop couples with no family respondent
* 3) Reshape dataset to couple structure (one row per couple) 
* 4) Drop homosexual couples
* 5) Generate "famresid" (the mergeid of the family respondent) for merging children data later on
* 6) Generate additional couple-level variables 
*    (e.g., job shares, employment configuration, education, age constellation)
* 7) add interview date from wave 1 to wave 2
* 
* Produces data output in temporary folder: 
* - Wave 1: 00-4_couples_wave1.dta
* - Wave 2: 00-4_couples_wave2.dta
* 
* Records in both files represent couples and not respondents. 
**********************************************************************/


foreach wave of numlist 1/2 {

quiet log on dataselection
di as txt "**********************************************"
di as txt "Preparing couples_wave`wave'"
di as txt "**********************************************"
quiet log off dataselection

* load prepared respondent data (see 00-1_respondents.do)
use "${tempDir}/00-1_respondents_wave`wave'", clear

* 1) Starting with respondent data, keep only respondents with responding partners in a household

capt drop  deadoralive 

quiet log on dataselection

* keep only persons with partner (= drop respondents without partner)
keep if cvidp < .

* keep only responding partners (= drop non-responding partners)
keep if status == 1

* keep only 1 & 2 cvids (simplification, since there are some few with cvid 3 and 4)
keep if cvid <= 2
drop if cvidp > 2

* keep only couple households with two respondents
by hhid`wave', sort: gen N = _N

* keep only households with two respondents being a couple 
keep if N==2

quiet log off dataselection

* 2) Select family respondent uniquely and drop couples with no family respondent
* some few couples have two family respondents; 
* if there are two family respondents let female respondents dominate (otherwise potentially different child information)
by hhid`wave', sort: replace dumfamr = 0 if gender==1 & (dumfamr[_n+1]==1 & dumfamr==1) | (dumfamr[_n-1]==1 & dumfamr==1)   

* drop couples with no family respondents
by hhid`wave', sort: drop if (dumfamr[_n+1]==0 & dumfamr==0) | (dumfamr[_n-1]==0 & dumfamr==0)   

* sort family respondent to first row
isid hhid`wave' dumfamr
gsort +hhid`wave' -dumfamr
by hhid`wave': gen j = _n

* 3) Reshape data set to couple structure (one row per couple) 
* reshape to wide (=> get couple data, one row per couple: x1 (spouse 1, = family respondent) & x2 (spouse 2) ) 
* (note: in wave 2, due to move-ins hhid1 is not necessarily constant over couples, thus take it wide too)
unab vars: mergeid waveid-dn014_ hhid? 
reshape wide `vars', i(hhid) j(j)

* assert that if a person is coverscreen respondent the partner is really a "partner"
assert inlist(relrpers2, 1,2) if relrpers1==.
assert inlist(relrpers1, 1,2) if relrpers2==.
	
* check: first partner is always family respondent now
assert dumfamr1==1
assert dumfamr2==0

* 4) Drop homosexual couples
quiet log on dataselection
* keep only heterosexual couples
assert !mi(gender1) & !mi(gender2)
drop if gender1==gender2
quiet log off dataselection

* 5) Generate "famresid" (the mergeid of the family respondent) for merging child data later 
* generate a new mergeid for merging childdata (prov. by the fam. respondent)
gen famresid = mergeid1

* 6) Generate additional couple-level variables

* 6.1) Employment: GF/GM working fulltime
* Binary indicator (using the "ft" variable generated on the respondent level, see 00-1_respondents.do)
gen gfft = ft1 if gender1==1
replace gfft = ft2 if gender2==1
gen gmft = ft1 if gender1==2
replace gmft = ft2 if gender2==2
lab var gfft "couple: GF fulltime (>=${fulltime} real working hours)"
lab var gmft "couple: GM fulltime (>=${fulltime} real working hours)"


* 6.2) Employment: couple's employment configuration
* a) at least one employed vs. b) both inactive
gen empcf = .
* a) 
replace empcf = 1 if gfft==1 & inlist(gmft,0,.)	// GF fulltime working, GM anything (e.g. non-fulltime working, retired, homemaker etc.)
replace empcf = 2 if gfft==1 & gmft==1	// GF & GM fulltime working
replace empcf = 3 if inlist(gfft,0,.) & gmft==1	// GM fulltime working, GF anything
replace empcf = 4 if (gfft==0 & gmft==0) | /// both employed/self-employed but not fulltime
					 (gfft==0 & gmft==.) | /// GF part-time, GM inactive
					 (gfft==. & gmft==0) // GF inactive, GM part-time
* b) 
replace empcf = 5 if (gfft==. & gmft==.) // none is employed/self-employed (both inactive)
capt lab drop empcf
lab def empcf 1 "GF ft (>=${fulltime})" 2 "both ft (>=${fulltime})" 3 "GM ft (>=${fulltime})" 4 "none ft (<${fulltime})" 5 "both retired/inactive"
lab val empcf empcf
lab var empcf "couple:  employment configuration (fulltime = min ${fulltime} hours)"		
quiet log off dataselection

* 6.3) Job share of spouses/partners
* job hours of couple (sum of partners' individual job hours as generated in 00-1_respondents.do)
gen double cpljobhrs = jobhrs1+jobhrs2
lab var cpljobhrs "couple: Total hours couple is working"
* Jobshare (%) of partner 1|2 = 100 x (job hours of partner 1)/(job hours of couple)
gen double jobshr1 = 100*jobhrs1/cpljobhrs
gen double jobshr2 = 100*jobhrs2/cpljobhrs
* Set partners' job share to 50%, if couple has 0 hours spent for working in job 
* zero jobhours: set share to 50 percent
replace jobshr1 = 50 if cpljobhrs == 0
replace jobshr2 = 50 if cpljobhrs == 0

* 6.4) Identifiy job hours and job share of Grandfather and Grandmother
gen double gfjobshr = jobshr1 if gender1==1
replace gfjobshr = jobshr2 if gender2==1
lab var gfjobshr "couple: jobshare of Grandfather"
gen double gmjobshr = jobshr1 if gender1==2
replace gmjobshr = jobshr2 if gender2==2
lab var gmjobshr "couple: jobshare of Grandmother"

gen double gfjobhrs = jobhrs1 if gender1==1
replace gfjobhrs = jobhrs2 if gender2==1
gen double gmjobhrs = jobhrs1 if gender1==2
replace gmjobhrs = jobhrs2 if gender2==2
lab var gfjobhrs "couple: job hours of Grandfather"
lab var gmjobhrs "couple: job hours of Grandmother"

* 6.5) Grandfather is retired
gen gfretired = ep005_1 == 1 if gender1==1
replace gfretired = ep005_2 == 1 if gender2==1

* 6.6) check employment variables
gen gfep005 = ep005_1 if gender1==1
replace gfep005 = ep005_2 if gender2==1
gen gmep005 = ep005_1 if gender1==2
replace gmep005 = ep005_2 if gender2==2
lab val gmep005 ep005
lab val gfep005 ep005

by empcf, sort: tab gfep005 gmep005, miss 

* 6.7) Education 
* ISCED of GF/GM
gen gfisced = isced_r1 if gender1==1
replace gfisced = isced_r2 if gender2==1
lab var gfisced "couple: Grandfather's ISCED"
gen gmisced = isced_r1 if gender1==2
replace gmisced = isced_r2 if gender2==2
lab var gmisced "couple: Grandmothers's ISCED"
* Highest ISCED in couple
gen hisced = max(isced_r1, isced_r2)
lab val hisced isced
* Binary indicator for highest ISCED in couple greater than 4 
gen cplisgt4 = hisced > 4 if !mi(hisced)
lab var cplisgt4 "couple: ISCED of one spouse > 4" 
* generate additional variable for isced > 3 (cf. Hank & Juerges)
gen cplisgt3 = hisced > 3 if hisced < .

* 6.8) Couple's age (=mean of spouses' age)
gen cplage = (age1+age2)/2
lab var cplage "couple: mean age of spouses"

* 6.9) Age difference in couple
gen cplygfo = max(0,age1-age2) if gender1==1
replace cplygfo = max(0,age2-age1) if gender2==1
lab var cplygfo "couple: years grandfather is older"
gen cplygmo = max(0,age2-age1) if gender1==1
replace cplygmo = max(0,age1-age2) if gender2==1
lab var cplygmo "couple: years grandmother is older"

* 6.10) Grandfather's and Grandmother's age
gen gfage = age1 if gender1==1
replace gfage = age2 if gender2==1
lab var gfage "couple: age of grandfather"
gen gmage = age1 if gender1==2
replace gmage = age2 if gender2==2
lab var gmage "couple: age of grandmother"

* 6.11) Limitations
gen gflimit = (ep005_1==4 | adl21==1) if gender1 == 1
replace gflimit = (ep005_2==4 | adl22==1) if gender2 == 1
gen gmlimit = (ep005_1==4 | adl21==1) if gender1 == 2
replace gmlimit = (ep005_2==4 | adl22==1) if gender2 == 2

gen cpllimit = 1 if gflimit==0 & gmlimit==0
replace cpllimit = 2 if gflimit==1 & gmlimit==0
replace cpllimit = 3 if gflimit==0 & gmlimit==1
replace cpllimit = 4 if gflimit==1 & gmlimit==1
lab var cpllimit "couple: perm. sick, disabled / ADL>=1"
lab def cpllimit 1 "none" 2 "only GF" 3 "only GM" 4 "both"
lab val cpllimit cpllimit

* 6.12) Marital state
gen gfmstat = mstat1 if gender1==1
replace gfmstat = mstat2 if gender2==1
gen gmmstat = mstat1 if gender1==2
replace gmmstat = mstat2 if gender2==2
lab val gfmstat mstat
lab val gmmstat mstat

gen gfdn014_ = dn014_1 if gender1==1
replace gfdn014_ = dn014_2 if gender2==1
gen gmdn014_ = dn014_1 if gender1==2
replace gmdn014_ = dn014_2 if gender2==2
lab val gfdn014_ marritalst
lab val gmdn014_ marritalst

* Save couples data set
save "${tempDir}/00-4_couples_wave`wave'", replace

}


* 7) add interview date from wave 1 to wave 2 
use "${tempDir}/00-1_respondents_wave1", clear

keep mergeid idate
rename idate idate_w1
tempfile idate
save `idate'

* merge interview date from wave 1 to couple data of wave 2
use "${tempDir}/00-4_couples_wave2", clear

clonevar mergeid = mergeid1
merge 1:n mergeid using `idate', keep(master matched) nogen
drop mergeid
rename idate_w1 idate_w11
order idate_w11, after(idate1)

clonevar mergeid = mergeid2
merge 1:n mergeid using `idate', keep(master matched) nogen
drop mergeid
rename idate_w1 idate_w12
order idate_w12, after(idate2)

save, replace



