/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
* 
* Preparation of multi-level couple-child data (00-5_couple-child-dyads.do), 
* executed by data preparation master 00_preparation.do
* 
* This step fuses couple and child data. The resulting datasets (for each wave) 
* have one row per couple and child (including child-specific grandparenting data). 
* This data structure is used in a later step to calculate grandparenting hours reported by the couples.
* This step also generates some additional variables on couple level.
*
* Note: couple-child-dyads include all children reported by the family respondent and not 
* only the children selected for detailed questions (marked by childdetail=1).
* 
* Requires prepared couple files (prepared in 00-4_couples.do) and 
* grandparenting files (prepared in 00-3_grandparenting.do)as input. 
*
* Produces data output in temporary folder: 
* - Wave 1: 00-5_couple-child-dyads_wave1.dta
* - Wave 2: 00-5_couple-child-dyads_wave2.dta
* 
**********************************************************************/

* loop over wave-specific data files
foreach wave of numlist 1/2 {

log on dataselection
di as txt "**********************************************"
di as txt "Preparing dyads_wave`wave'"
di as txt "**********************************************"
log off dataselection

* use prepared couple data (see 00-4_couples.do)
use  "${tempDir}/00-4_couples_wave`wave'", clear

log on dataselection
* Merge child data first; keep only couples that match with child data (i.e. have children)
merge 1:n famresid using "${tempDir}/00-2_children_wave`wave'"
drop if _merge!=3
drop _merge
log off dataselection


drop cvid

* add grandparenting data
tempfile first second
preserve 
	use "${tempDir}/00-3_grandparenting_wave`wave'", clear
	drop mergeid cvidp wave dumfamr
	renvars hhid? cvid-weekhours, suffix(1)
	save `first' 
	use "${tempDir}/00-3_grandparenting_wave`wave'", clear
	drop mergeid cvidp wave dumfamr
	renvars hhid? cvid-weekhours, suffix(2)
	save `second' 
restore	
	

* Merge grandparenting data
* 1) to first spouse
isid hhid`wave'1 cvid1 child
merge 1:1 hhid`wave'1 cvid1 child using `first', keep(master matched) 
gen gpdataavailable1 = _merge==3
drop _merge
* 2) to the second spouse
isid hhid`wave'2 cvid2 child
merge 1:1 hhid`wave'2 cvid2 child using `second', keep(master matched) 
gen gpdataavailable2 = _merge==3 
drop _merge


sharetom _all, replace

* Generate child level variables
* At least one child cohabiting 
* (assumption: if cohabitation data is missing due to DNKs etc., child mostly likely does not cohabite with gp couple)
by hhid, sort: gen c = (cdist==1)
by hhid, sort: egen cplcohab = max(c)
drop c
lab var cplcohab "couple: cohabitation with at least one child"

* age of youngest child (classified)
recode cycage (0 = 1 "0") ///
			  (1 2 = 2 "1-2") /// 
			  (3/5 = 3 "3-5") /// 
			  (6/12 = 4 "6-12") /// 
			  (13/max = 5 "13+"), gen(cycage_class)
lab var cycage_class "age of youngest grandchild (classified)"

* check integrity of child counter
isid hhid child
sort hhid child
assert child==child[_n-1]+1 if hhid==hhid[_n-1]

* save couple-child dyads
save "${tempDir}/00-5_couple-child-dyads_wave`wave'", replace

}



