/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Sample selection (10_sample.do), 
* executed by data preparation master 00_preparation.do

* This file completes the following steps: 
* I) 	Pool couple-child data from both waves
* II) 	Select samples of couples for both waves
*		- remove households that split up in wave 2
*		- preserve only couple-child dyads with detailed child data (i.e., data on grandparenting)
*	    - select only couples whose youngest grandchild is 12 or younger
*  		- restrict to both spouses providing non-missing information about looking after grandchildren and 
*			at least one spouse reports to look after grandchildren
*
* Produces data output in temporary folder: 
* - 10_sample.dta
* 
***********************************************************************/

run config
set more off

log using "${logDir}/sampleselection.smcl", smcl replace name(sampleselection)
log on sampleselection

*************************************
* I) Pool dyad data from wave 1 & 2
*************************************
use "${tempDir}/00-5_couple-child-dyads_wave1.dta", clear 

* no. of couples in wave 1 and in countries of our sample
di "no. of couples in wave 1 and in countries of our sample"
distinct hhid1 if wave==1 & !inlist(country, 25,28,29,30)

* append second wave
append using "${tempDir}/00-5_couple-child-dyads_wave2.dta"

di "no. of couples in wave 2 and in countries of our sample"
distinct hhid2 if wave==2 & !inlist(country, 25,28,29,30)

* drop Israeli cases (Israel only participated in first wave)
drop if country==25
* drop CZ,PL, and IRL (onyl wave 2)
drop if inlist(country, 28, 29, 30)
* drop Switzerland (we decided to exclude due to low case number)
drop if country == 20

* number of couples / obs after dropping countries
distinct hhid1 if wave==1 
distinct hhid2 if wave==2

order hhid2, after(hhid)


*********************************************
* II) Sample Selection
*********************************************

*********************************************
* 1.) Sample selection on the child level
*********************************************

* remove split households in wave 2 (former partners separated into different households, cannot be considered as couple any longer)
merge n:1 hhid2 wave using "${tempDir}/00-0_households_wave2", assert(master matched using) keep(master matched) nogen keepusing(split)
drop if split==1 // 0 cases
drop split

* select only children who were selected for detail questions (up to 4; only for those we have needed data like age of youngest child)
keep if childdetail == 1

* select only those children whose youngest child is 12 or younger (an drop cases with missing info)
keep if cycage <= 12
* for robustness check change that cut off (our checks showed, that results do not change substantially) 
* keep if cycage <= 16
* keep if cycage <= 10

di "no. of couples in wave 1 & 2 and in countries of our sample have gc <= 12 years"
distinct hhid1 if wave==1 
distinct hhid2 if wave==2 

* select only cases of grandparents where 
* (a) both spouses provide non-missing information on item sp014_ (looking after grandchildren) and 
* (b) at least one spouse is looking for grandchildren
* => a)
keep if !mi(sp014_1) & !mi(sp014_2)
distinct hhid1 if wave==1 
distinct hhid2 if wave==2 
* over all %-loss of couples by this operation (~12.4%)
di 1 - (4044+ 3356) / (4171+4272)

* => b)
keep if sp014_1==1 | sp014_2==1

di "no. of couples in wave 1 & 2 with at least one reporting looking after gc"
distinct hhid1 if wave==1 
distinct hhid2 if wave==2 

* over all %-loss of couples by both operations (~35.8%)
di 1 - (2981+ 2436) / (4171+4272)

log off sampleselection
log close sampleselection

* save sample data
save "${tempDir}/10_sample", replace



