/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Imputes missing values and generates dependent variable and other variables (20_variables_imputation.do), 
* executed by _PROJECT_MASTER_.do  
* 
* Impute and generate weekly hours at the dyad level
* 
* 1) solve some data problems 
*    - remove a few observations/couples in which respondents did not specifiy a child in the looping question for looking after grandchildren
*    - implausible zero hours are coded to the lowest value
* 2) generate a metric variable weekhours ("weekly hours of looking after children of child")
*    - coding scheme according to Ghysels (2011) 
*    - top-coding to max 60 hours weekly per child
*    - zero hours for children of children not selected by the respondents  
* 3) single imputation of missing values in weekhours (note: imputation done without restriction to youngest child of child <=12)
*	 - three OLS models predicting missing values
*    - regression of log-transformation of weekhours (ensures that only positive values are predicted)
*	 - three imputation models
*    - imputation model 3 accounting for partner variables and non-linear functional forms performs best (by far highest R2 of ~.36) 
*	 - imputations from model 3 will be used later in the analysis
* 4) generate the dependent variable gfshr (grandfather's share of couple's total hours of looking after grandchildren)
*    - sum up weekly hours (including imputed values) over spouses and couples
*    - %GF = 100 x sum(weekhours of GF)/[sum(weekhours of GF) + sum(weekhours of GM)] 
* 5) aggregate couple-child dyads to couple-level data
*
* Produces data output in temporary folder: 
* - 20_variables_imputation.dta
*
* References:
* Ghysels, J. 2011. The Provision of Informal Childcare by European Grandparents: Constraints versus Selective Preferences. CSB Working Paper No. 11/08.
*
**********************************************************************/

run config
set more off

log using "${logDir}/sampleselection.smcl", smcl append name(sampleselection)
log off sampleselection
log using "${logDir}/imputation.smcl", smcl replace name(imputation)
log off imputation

log on imputation
* load couple-child-dyad data
use "${tempDir}/10_sample", clear

* data consistency check
distinct hhid1 if wave==1
assert `r(ndistinct)' ==  2981 //  2981 couples in wave 1
distinct hhid2 if wave==2
assert `r(ndistinct)' == 2436 // 2436 couples in wave 2
count if wave == 1 
assert `r(N)' == 4688 // 4688 obs in wave 1
count if wave == 2 
assert `r(N)' == 3822 // 3822 obs in wave 2

******************************************************************
*
* Generate variable "weekhours"
* = number of hours weekly spent for looking after grandchildren 
*   of a specific child
* 
* Coding follows a scheme developed 
* by Ghysels (2006)
*
* weekhours is a central variable for the construction of the 
* dependent variable gfshr (grandfather's overall caring share)
*
* grandfather's share = 
* sum(weekhours of GF) / [ sum(weekhours of GF) + sum(weekhours of GM) ] 
* 
******************************************************************
capt drop weekhours1
capt drop weekhours2

***************************
* 1) Solve data problems 
***************************

* first: 
* Drop entries where respondents don't know/refused 
* if they looked to children of selected child
* drop 5 cases: both are looking, but refuse/don't know to child n
li sp0* if sp014_1==1 & sp014_2==1 & sp015d1>. & sp015d2>.
drop if sp014_1==1 & sp014_2==1 & sp015d1>. & sp015d2>.
* 0 cases: spouse 1 is looking, but refuse/don't know to child n
drop if sp014_1==1 & sp015d1>.
* 7 cases: spouse 2 is looking, but refuse/don't know to child n
drop if sp014_2==1 & sp015d2>.

* check case numbers
distinct hhid1 if wave==1
assert `r(ndistinct)' == 2977 
distinct hhid2 if wave==2
assert `r(ndistinct)' == 2431 // lost 8 couples in wave 2; now 2675 couples in wave 2
count if wave == 1 
assert `r(N)' == 4682 
count if wave == 2 
assert `r(N)' == 3816 // lost 18 obs in wave 2; now 6684 3obs in wave 2


* Solve problem with zero hours of looking after gc
* correct variable 
* sp017_ (number of hours looking rounded up to full hours)
* Problem: there are some few zero hours
* 63 cases with zero hours, however specified to be looking for children of that child
count if sp017_1==0 & sp015d1==1
count if sp017_2==0 & sp015d2==1

* conservative estimate: insert lowest value above 0 of respective frequency category
fre sp016_1 if sp017_1==0 & sp015d1==1
fre sp016_2 if sp017_2==0 & sp015d2==1
* insert lowest values, but before, save original variable
gen sp017_org_1 = sp017_1 // save original values
gen sp017_org_2 = sp017_2 // save original values
order sp017_org_1, after(sp017_1)
order sp017_org_2, after(sp017_2)

* now correct zero values
* cat 1: almost daily
* (spouse 1) 
sum sp017_1 if sp017_1>0 & sp016_1==1 & sp015d1==1 
local min1 = `r(min)'
* (spouse 2) 
sum sp017_2 if sp017_2>0 & sp016_2==1 & sp015d2==1 
local min2 = `r(min)'
replace sp017_1 = min(`min1', `min2') if sp017_1==0 & sp016_1==1 & sp015d1==1 
replace sp017_2 = min(`min1', `min2') if sp017_2==0 & sp016_2==1 & sp015d2==1 
* cat 2: almost every week
* (spouse 1) 
sum sp017_1 if sp017_1>0 & sp016_1==2 & sp015d1==1 
local min1 = `r(min)'
* (spouse 2) 
sum sp017_2 if sp017_2>0 & sp016_2==2 & sp015d2==1 
local min2 = `r(min)'
replace sp017_1 = min(`min1', `min2') if sp017_1==0 & sp016_1==2 & sp015d1==1 
replace sp017_2 = min(`min1', `min2') if sp017_2==0 & sp016_2==2 & sp015d2==1 
* cat 3: almost every month
* (spouse 1) 
sum sp017_1 if sp017_1>0 & sp016_1==3 & sp015d1==1 
local min1 = `r(min)'
* (spouse 2) 
sum sp017_2 if sp017_2>0 & sp016_2==3 & sp015d2==1 
local min2 = `r(min)'
replace sp017_1 = min(`min1', `min2') if sp017_1==0 & sp016_1==3 & sp015d1==1 
replace sp017_2 = min(`min1', `min2') if sp017_2==0 & sp016_2==3 & sp015d2==1 
* cat 4: less often
* (spouse 1) 
sum sp017_1 if sp017_1>0 & sp016_1==4 & sp015d1==1 
local min1 = `r(min)'
* (spouse 2) 
sum sp017_2 if sp017_2>0 & sp016_2==4 & sp015d2==1 
local min2 = `r(min)'
replace sp017_1 = min(`min1', `min2') if sp017_1==0 & sp016_1==4 & sp015d1==1 
replace sp017_2 = min(`min1', `min2') if sp017_2==0 & sp016_2==4 & sp015d2==1 

* check
assert sp017_1!=0 if sp015d1==1
assert sp017_2!=0 if sp015d2==1
***************

**********************
* 2) code weekly hours of looking after grandchilren
**********************
foreach num of numlist 1/2 {
* generate week hours indicator (according to Ghysels, 2011)
* daily: hours * 5
* weekly: hours
* monthly: hours / 4
* less often: hours / [52/weeks since last interview]
 
gen double weekhours`num' = cond(sp016_`num'==1,5*sp017_`num', ///
							cond(sp016_`num'==2,sp017_`num', ///
								 cond(sp016_`num'==3,sp017_`num'/4,  /// 
									  cond(sp016_`num'==4,sp017_`num'/52,.))))
									  
* top-coding extrem values (max 12 hours, 5 days a week)
replace weekhours`num' = 60 if !mi(weekhours`num') & weekhours`num' > 60  							   
* (140 changes)
lab var weekhours`num' "grandp.-child: weekly hours (coded) looking for children of child (cf. Ghysels, 2006)"

* if person declares not to look for grandchildren generally set weekhours to 0
assert weekhours`num' == . if sp014_`num'==5
replace weekhours`num' = 0 if sp014_`num'==5
replace weekhours`num' = 0 if inlist(sp015d`num',0,.)
	
}

* check: no zero hours if resp. looking for children of child n
assert weekhours1!=0 if sp015d1==1
assert weekhours2!=0 if sp015d2==1


************************
*
* Generate data aggregated over selected dyads
* Important: this step has to be done after dropping any dyads! 
*
************************
* distance to nearest child
by wave mergeid1 mergeid2, sort: egen mincdist = min(cdist)
lab val mincdist cdist
lab var mincdist "couple: distance to the nearest child with children"

* age of youngest grandchild
by wave mergeid1 mergeid2, sort: egen mincycage = min(cycage)
by wave mergeid1 mergeid2, sort: egen mincycage_class = min(cycage_class)
lab val mincycage_class cycage_class 
lab var mincycage "couple: age of youngest grandchild selected"
lab var mincycage_class "couple: age of youngest grandchild selected (classified)"

* biological status of youngest grandchild is own child?
by wave mergeid1 mergeid2, sort: gen markchild = (cycage==mincycage)
* if there are two or more grandchildren with same age take status of first one within a wave (ordered by child)
* Example: li hhid wave mergeid1 mergeid2 child markchild cycage cstat if mergeid1 == "Bn-338102-01"
foreach num of numlist 1/4 {
	by wave mergeid1 mergeid2 (child), sort: replace markchild = 0 if markchild==1 & markchild[_n-`num']==1    
}
* check integrity
by wave mergeid1 mergeid2, sort: egen check = total(markchild)
assert check==1
drop check

* gen status of this child
gen _ygcstat = cstat if markchild==1
by wave mergeid1 mergeid2, sort: egen ygcstat = max(_ygcstat)
drop _ygcstat
lab val ygcstat cstat

* relation to gm & gf
* (remember: spouse 1 is always the family respondent)
gen gfygcown = 1 if ygcstat==1
replace gfygcown = 1 if ygcstat == 2 & gender1==1
replace gfygcown = 1 if ygcstat == 3 & gender2==1
replace gfygcown = 0 if gfygcown==.

gen gmygcown = 1 if ygcstat==1
replace gmygcown = 1 if ygcstat == 2 & gender1==2
replace gmygcown = 1 if ygcstat == 3 & gender2==2
replace gmygcown = 0 if gmygcown==.

lab var gfygcown "couple: youngest grandchild biolog. rel. to grandfather"
lab var gmygcown "couple: youngest grandchild biolog. rel. to grandmother"

* code a dummy for youngest grandchild not of own child
gen gfygcnotown = gfygcown==0
* code a dummy for nearest child with child is in the same household or up to 5 km away
gen shortdist = inlist(mincdist,1,2) 

* number of children for who couples provides care
gen care = !(weekhours1==0 & weekhours2==0) // care is given (=1) if spouses do not provide zero hours to a child (missing values will be imputed later)
by hhid wave (child), sort: egen caredchild = total(care)
lab var caredchild "number of children to whom couple provides care"

tempfile sample
save `sample', replace 


************************
* 3) Single imputation of missing values in weekhours
*
* Three models estimated via OLS. Model 3 is favorable. 
*
************************

* data consistency check
distinct hhid1 if wave==1
distinct hhid2 if wave==2
count if wave == 1 
count if wave == 2 

* about 7.63% of couple-child-dyads miss values in weekhours
tempvar miss
gen `miss' = mi(weekhours1) | mi(weekhours2)
fre `miss'

* about 3% of couple-child-days miss values in weekhours for both partners
tempvar miss2
gen `miss2' = mi(weekhours1) & mi(weekhours2)
fre `miss2'

* data consistency check
assert mergeid==mergeid1
drop mergeid

* keep only relevant variables
keep hhid mergeid? wave n mstat? gender? age? country cage cycage cdist jobhrs? weekhours? isced_r? dumfamr? sp014_* sp015d? sp016_* sp017_*

* generate a variable for number of children-dyads
by hhid wave, sort: gen cdyadsbywave = _N

* generate partner values
gen weekhours_partner1 = weekhours2 
gen weekhours_partner2 = weekhours1
gen isced_partner1 = isced_r2
gen isced_partner2 = isced_r1
gen age_partner1 = age2
gen age_partner2 = age1
gen jobhrs_partner1 = jobhrs2
gen jobhrs_partner2 = jobhrs1

* reshape to long data structure
reshape long mergeid mstat gender age jobhrs isced_r dumfamr weekhours sp015d sp014_ sp016_ sp017_ ///
			 weekhours_partner isced_partner age_partner jobhrs_partner, i(hhid wave n)

isid hhid wave n _j 
sort hhid wave n _j 

* check number of missing values and missing patterns
misstable summarize wave gender age country cage cycage cdist jobhrs weekhours
mvpatterns wave gender age country cage cycage cdist jobhrs

* missing dummy coding for few cases having mv's in cage
gen cage_miss = mi(cage)
replace cage = 0 if cage_miss == 1
* missing dummy coding for few cases having no isced value
gen isc_miss = mi(isced_r)
replace isced_r = 0 if isc_miss == 1
* same for partner isced
gen isc_partner_miss = mi(isced_partner)
replace isced_partner = 0 if isc_partner_miss == 1
* missing coding for partner's weekhours
gen weekhours_partner_miss = mi(weekhours_partner)
replace weekhours_partner = 0 if weekhours_partner_miss==1

gen jobhrs_miss = mi(jobhrs)
gen jobhrs_partner_miss = mi(jobhrs_partner)
replace jobhrs = 0 if mi(jobhrs)
replace jobhrs_partner = 0 if mi(jobhrs_partner)

misstable summarize wave gender age country cage cage_miss cycage cdist jobhrs jobhrs_miss isced_r isc_miss mstat /// 
					isced_partner isc_partner_miss age_partner jobhrs_partner weekhours weekhours_partner weekhours_partner_miss jobhrs_partner_miss

* Check data consistency
* a) always zero hours if respondents declares not to look after gc at all
assert weekhours == 0 if sp014_==5 
* b) respondents looking after gc: 
assert weekhours !=0 if sp015d==1 & sp014_ == 1

* assert that sp015d=1 (respondent selected child)
assert sp015d==1 if mi(weekhours)					
					
gen wkhrs_imputed = mi(weekhours)

* log-transformation, since we want no predicted values of zero or below
gen lnweekhours = ln(weekhours) if sp015d==1

* Model 1
regress lnweekhours i.wave i.gender c.age i.country c.cage cage_miss c.cycage i.cdist c.jobhrs jobhrs_miss if sp015d==1
est store mod1
predict yhat_1 if sp015d==1, xb
gen wkhrs_impmod1 = weekhours
replace wkhrs_impmod1 = exp(yhat_1) if mi(wkhrs_impmod1) 
* check distribution
histogram wkhrs_impmod1, by(wkhrs_imputed )
	
* Model 2 (+ ISCED)
regress lnweekhours i.wave i.gender c.age i.country c.cage cage_miss c.cycage i.cdist c.jobhrs jobhrs_miss i.isced_r isc_miss  if sp015d==1
est store mod2
predict yhat_2, xb
gen wkhrs_impmod2 = weekhours
replace wkhrs_impmod2 = exp(yhat_2) if mi(wkhrs_impmod2) 
* check distribution
histogram wkhrs_impmod2, by(wkhrs_imputed )

* Model 3 (+ partner Variables, number of dyads and non-linear functional forms)
regress lnweekhours i.wave i.gender c.age##c.age i.country c.cage cage_miss c.cycage i.cdist c.jobhrs jobhrs_miss i.mstat cdyadsbywave /// 
					  i.isced_r isc_miss i.isced_partner isc_partner_miss ///
					  c.age_partner##c.age_partner c.jobhrs_partner##c.jobhrs_partner jobhrs_partner_miss c.weekhours_partner##c.weekhours_partner weekhours_partner_miss /// 
					  if sp015d==1
est store mod3
predict yhat_3, xb
gen wkhrs_impmod3 = weekhours
replace wkhrs_impmod3 = exp(yhat_3) if mi(wkhrs_impmod3) 
* check distribution
histogram wkhrs_impmod3, by(wkhrs_imputed )

* compare models
* BIC/AIC => lower is better; mod3 preferrable
est stats mod1 mod2 mod3
* (adjusted) R2 => higher is better (since it gives better predictions); mod3 favorable 
est table mod1 mod2 mod3, newpanel stats(N df_m r2 r2_a) b(%9.3f)

* top-code imputed variables (has no effect here since no valuess beyond 60 hrs)
foreach var of varlist wkhrs_impmod* {
	replace `var' = 60 if `var' > 60 & `var' < .
}
* distribution of weekhours with and without imputed values
histogram weekhours, name(noimp, replace)
histogram wkhrs_impmod3, name(withimp, replace)

* compare mean values and standard deviations
sum weekhours wkhrs_impmod*
* model 3 predicts the lowest mean
* mean for full cases (including imputations) lower than for non-missing cases only (lowest for model 3)
* (suggests that non-responders are more likely to do less hours)
* correlations between different imputation models

* check: maximal weekhours do not exceed boundary of 60 hrs
sum wkhrs_impmod3
assert `r(max)' <= 60
					  
*******************************************
* prepare imputation data for merging
*******************************************
* Keep only relevant variables
keep hhid wave n _j mergeid gender weekhours wkhrs_*

* label variables
lab var wkhrs_impmod1 "Imputation (OLS): basic model (original one)"
lab var wkhrs_impmod2 "Imputation (OLS): model 2 (basic model + ISCED)"
lab var wkhrs_impmod3 "Imputation (OLS): model 3 (+ partner values/functional terms)"
lab var wkhrs_imputed "imputation for weekhours"


* reshape the data structure to wide
reshape wide mergeid gender weekhours ///
			 wkhrs_imputed wkhrs_impmod1 wkhrs_impmod2 wkhrs_impmod3 , i(hhid wave n) j(_j)

* pairwise correlations of weekhours between partners
* a) original values (~.59)
pwcorr weekhours1 weekhours2
* b) imputed values
* mod 1-OLS (~.58)
pwcorr wkhrs_impmod11 wkhrs_impmod12
* mod 2-OLS (~.58)
pwcorr wkhrs_impmod21 wkhrs_impmod22			 
* mod 3-OLS (~.60)
pwcorr wkhrs_impmod31 wkhrs_impmod32			 
* plausible: mod3 imputations higher correlation, since mod3 accounted for partner variables		 
			 
* generate mergeid variable for merging again
gen mergeid = mergeid1			 
* save imputed values
tempfile imputation
save `imputation', replace

*****************************************
* Merge prepared imputations to the analytical dataset
* and removal of some cases (missing obs)
*****************************************

* Add imputation values to the dataset
use `sample', clear
merge 1:1 hhid wave mergeid n gender1 using `imputation', assert(master match)

* we lost observations due to missing values (see above)
drop if _merge==1
drop _merge

* mark rows with at least one imputed value
gen wkhrs_imputed = wkhrs_imputed1==1 | wkhrs_imputed2==1
* 7.52% imputed values (i.e. have missing value for at least one partner)
fre wkhrs_imputed 

*****************************************
* 4) Constructing the dependent variable gfshr (Grandfather's share of looking)
*****************************************

* Generate share and amount variables based on imputations (for different models)
foreach mod in impmod1 impmod2 impmod3  {
foreach num of numlist 1/2 {
	by wave mergeid1 mergeid2, sort: egen sumwkhrs_`mod'`num' = total(wkhrs_`mod'`num')
	assert sumwkhrs_`mod'`num' >= 0 & sumwkhrs_`mod'`num' < .
}

gen cplsumwkhrs_`mod' = sumwkhrs_`mod'1+sumwkhrs_`mod'2

gen double shr1_`mod' = 100*sumwkhrs_`mod'1/cplsumwkhrs_`mod' 
gen double shr2_`mod' = 100*sumwkhrs_`mod'2/cplsumwkhrs_`mod' 

gen double gfcarehrs_`mod' = sumwkhrs_`mod'1 if gender1==1
replace gfcarehrs_`mod' = sumwkhrs_`mod'2 if gender2==1

gen double gmcarehrs_`mod' = sumwkhrs_`mod'1 if gender1==2
replace gmcarehrs_`mod' = sumwkhrs_`mod'2 if gender2==2

gen double gfshr_`mod' = 100*gfcarehrs_`mod'/cplsumwkhrs_`mod' if gender1==1
replace  gfshr_`mod' = 100*gfcarehrs_`mod'/cplsumwkhrs_`mod' if gender2==1

gen double gmshr_`mod' = 100*gmcarehrs_`mod'/cplsumwkhrs_`mod' if gender1==2
replace  gmshr_`mod' = 100*gmcarehrs_`mod'/cplsumwkhrs_`mod' if gender2==2

lab var cplsumwkhrs_`mod' "couple (`mod'): sum of caring hours for all selected grandchildren "
lab var gfshr_`mod' "couple (`mod'): grandfather's share of caring"
lab var gmshr_`mod' "couple (`mod'): grandmothers's share of caring"
lab var gfcarehrs_`mod' "couple (`mod'): grandfather's caring hours"
lab var gmcarehrs_`mod' "couple (`mod'): grandmothers's caring hours"

}
 
sum gfshr_*
sum gmshr_*
sum gfcarehrs_*
sum gmcarehrs_*
sum cplsumwkhrs_*

* those variables should have no missings
misstable summarize cplsumwkhrs_*
misstable summarize sumwkhrs_*1
misstable summarize sumwkhrs_*2
* share variables could have different number of missing values, since it depends on how often couplehours are estimated to zero!
misstable summarize gfshr_*

* those with missing values inf gfshr_* are those with zero total hours (will be discarded later) 
assert gfshr_impmod3==. if  cplsumwkhrs_impmod3==0

* check that 
foreach mod in impmod1 impmod2 impmod3  {
	assert cplsumwkhrs_`mod' ==0 if mi(gfshr_`mod')
	assert mi(gfshr_`mod') if cplsumwkhrs_`mod' ==0 
}

* top code total hours of grandparenting to 120 
replace cplsumwkhrs_impmod3 = 120 if cplsumwkhrs_impmod3 > 120 & cplsumwkhrs_impmod3 < .


log on sampleselection
* drop if couples have missing values on essential variables
misstable summarize gfshr_* cplsumwkhrs_* empcf cplage mincdist cplisgt3 mincycage gfygcnotown 
egen miss = rowmiss(empcf cplage mincdist cplisgt3 mincycage gfygcnotown gmjobshr) 
* drop 168 cases with missing data on relevant variables
count if miss==1
assert `r(N)'==168
drop if miss > 0 // 168 obs 
log off sampleselection


save `sample', replace


************************************************
* 5) Get back to couple-level data
************************************************
use `sample', clear

* keep only relevant variables
keep mergeid? wave* hhid cplage caredchild cplygfo cplygmo cplcohab cpllimit cpljobhrs empcf jobhrs* job?hrs* gf* gm* mincdist shortdist mincycage mincycage_class cplisgt* hisced country cplsumwkhrs_* 
* drop within-wave duplicates to return to couple data format
duplicates drop wave mergeid1 mergeid2, force

* couples of wave 2 who already had participated in wave 1
by hhid (wave), sort: gen waves = _N
* 1115 couples taking part in both waves 
count if wave==2 & waves==2 
assert `r(N)' == 1115

* gen an indicator for couples having two-wave info
gen twowaves = waves==2

by hhid (wave), sort: gen first = _n==1
* effectively 4238 unique couples, since some participate in two waves
count if first==1
assert `r(N)' == 4185
drop first

save "${tempDir}/20_variables_imputation", replace

capt log off imputation
capt log close imputation
capt log off sampleselection
capt log close sampleselection

clear
exit

