/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Additional analyses assessing the selectivity of attrition from wave 1 to wave 2 
* (30-4_addon_panel_attrition.do), executed by analysis master 30_analysis.do
*
* Panel attrition is assessed for 
* - respondent level
* - household level
* - couple level (-> endnote 8 in paper)
* - grandparent couple level (-> endnote 8 in paper)
*
* Furthermore, a selectivity analysis for panel attrition of 
* grandparenting couples is conducted, for which results are reported in Endnote 8.
*
**********************************************************************/

* wave 2 participation (= responding in wave 2)
use "${tempDir}/00-1_respondents_wave2", clear
keep if status==1
tempfile w2part
save `w2part'

* open wave 1 respondent file
use "${tempDir}/00-1_respondents_wave1", clear

* restrict to eligible targets
keep if status==1

* generate a binary indicator for participation in wave 2
keep mergeid hhid wave country 
merge 1:1 mergeid using `w2part', keep(master matched) keepusing(mergeid)
gen w2part = _merge==3
drop _merge

**************
* Attrition in wave 2 on the respondent level 
**************
tab country w2part , miss
tab country w2part , row nofre

**************
* Attrition in wave 2 on the household level 
**************
* non-responding households (no one respondent in a given household in the second wave)
by hhid, sort: egen hhw2part = max(w2part)
by hhid, sort: gen first = _n==1

* 21319 HH in wave 1
count if first==1

tab country hhw2part if first==1
tab country hhw2part if first==1, row nofreq


***************
* Attrition in wave 
* on the couple level 
* (all couples, homosexual couples are excluded)
***************
use "${tempDir}/00-4_couples_wave2", clear

keep hhid mergeid1 mergeid2
rename mergeid1 mergeid1_w2
rename mergeid2 mergeid2_w2

tempfile w2part
save `w2part'

* open wave 1 couple file
use "${tempDir}/00-4_couples_wave1", clear
merge 1:1 hhid using `w2part', keep(master matched) 

gen hhw2part = _merge==3

* attrition of "couple households" 
tab country hhw2part, miss
tab country hhw2part, row nofreq

* attrition of "effective" couples (considering that couples do not exist any longer due to partner change)
gen cplinw2 = (mergeid1==mergeid1_w2 & mergeid2==mergeid2_w2) | ///
	          (mergeid1==mergeid2_w2 & mergeid1==mergeid2_w2) 

* 99.82% of couples selected in w1 are still couples in w2			  
fre cplinw2 if hhw2part==1

* attrition of "effective" couples 
tab country cplinw2, miss
tab country cplinw2, row nofreq


*************************
* Endnote 8: baseline attrition of couples between wave 1 & wave 2
*************************
* attrition of "effective" couples in countries under study
tab country cplinw2 if inlist(country,11,12,13,14,15,16,17,18,19,23), row nofreq
* overall couple attrition of 40.29%



* attrition of grandparent couples in our sample
use "${tempDir}/20_variables_imputation", clear			  

isid hhid wave

drop if wave == 2

gen cplinw2 = twowaves == 1

tab country cplinw2, miss
tab country cplinw2, row nofreq

*************************
* Endnote 8: attrition of grandparent couples between wave 1 & wave 2
*************************
tab country cplinw2 if inlist(country,11,12,13,14,15,16,17,18,19,23), row nofreq



*************************
* Endnote 8: how selective is the attrition of couples?
*************************
* logisitic regression of wave 2 data on several covariates
logit cplinw2 i.empcf cplisgt3 cplage i.cpllimit i.country mincycage shortdist mincdist cplsumwkhrs_impmod3 gfshr_impmod3, or	 	  
// result: 
// - country differences in participation, 
// - significant but small effect (in absolute terms) of couple's weekly caring hours on wave 2 data
// - however, no significant effect of grandfather's share 
// - no evidence for selectivity regarding socio-demographic variables
// - significant negative effect of age of youngest grandchild (plausible due to sample constraints of grandchildren <= 12 years old)

tabstat gfjobshr cpljobhrs cplisgt3 cplage mincycage cplsumwkhrs_impmod3 gfshr_impmod3, by(cplinw2) f(%9.2f)

