/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Additional selectivity analysis (30-5_addon_selectivity_of_sample.do), 
* executed by analysis master 30_analysis.do
*
* This files documents an analysis that assesses the selectivity of couples 
* performing grandchild care (the analytical sample). We compare couples who 
* reported no grandchild care with couples who reported at least some care. 
* The results are documented in this file, but not reported in the paper. 
*
* Background: 
* We focused only on active grandparent couples because our outcome of interest, 
* the gender gap in grandparenting, was predicated on at least some involvement 
* in grandchild care. We decided to restrict our analysis in this way to ensure 
* that our analytical approach is consistent with the theoretical perspective on
* the division of labor in couples. These theories invoke at least some performance 
* of non-market activities. We realize that unlike housework and parenting, looking 
* after grandchildren can often be regarded as an optional activity not necessarily 
* performed by any partner. Therefore, our results cannot be generalized to the 
* whole population of grandparent couples but only to those who provided at least 
* some grandchild care. 
* 
* Results:
* Additional analyses (provided in this file) show that grandparents in couples 
* who provided grandchild care are more likely to be employed, work more hours, 
* are less likely to have limitations in activities of daily living, and are 
* about 4 years younger on average than those in couples who did not report any 
* grandchild care.
* 
***********************************************************************/

* Pool caring (analytical sample) and not-caring grandparents (excluded from the 
* analytical sample)

* >>>>> SNIPPED FROM 10_sample.do
 
*************************************
* I) Pool dyad data from wave 1 & 2
*************************************
use "${tempDir}/00-5_couple-child-dyads_wave1.dta", clear 

* no. of couples in wave 1 and in countries of our sample
di "no. of couples in wave 1 and in countries of our sample"
distinct hhid1 if wave==1 & !inlist(country, 25,28,29,30)

* append second wave
append using "${tempDir}/00-5_couple-child-dyads_wave2.dta"

di "no. of couples in wave 2 and in countries of our sample"
distinct hhid2 if wave==2 & !inlist(country, 25,28,29,30)

* drop Israeli cases (Israel only participated in first wave)
drop if country==25
* drop CZ,PL, and IRL (onyl wave 2)
drop if inlist(country, 28, 29, 30)
* drop Switzerland (we decided to exclude due to low case number)
drop if country == 20

* number of couples / obs after dropping countries
distinct hhid1 if wave==1 
distinct hhid2 if wave==2

order hhid2, after(hhid)


*********************************************
* II) Sample Selection
*********************************************

*********************************************
* 1.) Sample selection on the child level
*********************************************

* remove split households in wave 2 (former partners separated into different households, cannot be considered as couple any longer)
merge n:1 hhid2 wave using "${tempDir}/00-0_households_wave2", assert(master matched using) keep(master matched) nogen keepusing(split)
drop if split==1 // 0 cases
drop split

* select only children who were selected for detail questions (up to 4; only for those we have needed data like age of youngest child)
keep if childdetail == 1

* select only those children whose youngest child is 12 or younger (an drop cases with missing info)
keep if cycage <= 12
* for robustness check change that cut off (our checks showed, that results do not change substantially) 
* keep if cycage <= 16
* keep if cycage <= 10

di "no. of couples in wave 1 & 2 and in countries of our sample have gc <= 12 years"
distinct hhid1 if wave==1 
distinct hhid2 if wave==2 

* select only cases of grandparents where 
* (a) both spouses provide non-missing information on item sp014_ (looking after grandchildren) and 
* (b) at least one spouse is looking for grandchildren
* => a)
keep if !mi(sp014_1) & !mi(sp014_2)
distinct hhid1 if wave==1 
distinct hhid2 if wave==2 
* over all %-loss of couples by this operation (~12.4%)
di 1 - (4044+ 3356) / (4171+4272)

* <<<<< SNIPPED FROM 10_sample.do

* Now, do drop caring grandparents (instead of not caring grandparents)
drop if sp014_1==1 | sp014_2==1

* distance to nearest child
by wave mergeid1 mergeid2, sort: egen mincdist = min(cdist)
lab val mincdist cdist
lab var mincdist "couple: distance to the nearest child with children"

* age of youngest grandchild
by wave mergeid1 mergeid2, sort: egen mincycage = min(cycage)
by wave mergeid1 mergeid2, sort: egen mincycage_class = min(cycage_class)
lab val mincycage_class cycage_class 
lab var mincycage "couple: age of youngest grandchild selected"
lab var mincycage_class "couple: age of youngest grandchild selected (classified)"

* biological status of youngest grandchild is own child?
by wave mergeid1 mergeid2, sort: gen markchild = (cycage==mincycage)
* if there are two or more grandchildren with same age take status of first one within a wave (ordered by child)
* Example: li hhid wave mergeid1 mergeid2 child markchild cycage cstat if mergeid1 == "Bn-338102-01"
foreach num of numlist 1/4 {
	by wave mergeid1 mergeid2 (child), sort: replace markchild = 0 if markchild==1 & markchild[_n-`num']==1    
}
* check integrity
by wave mergeid1 mergeid2, sort: egen check = total(markchild)
assert check==1
drop check

* gen status of this child
gen _ygcstat = cstat if markchild==1
by wave mergeid1 mergeid2, sort: egen ygcstat = max(_ygcstat)
drop _ygcstat
lab val ygcstat cstat

* relation to gm & gf
* (remember: spouse 1 is always the family respondent)
gen gfygcown = 1 if ygcstat==1
replace gfygcown = 1 if ygcstat == 2 & gender1==1
replace gfygcown = 1 if ygcstat == 3 & gender2==1
replace gfygcown = 0 if gfygcown==.

gen gmygcown = 1 if ygcstat==1
replace gmygcown = 1 if ygcstat == 2 & gender1==2
replace gmygcown = 1 if ygcstat == 3 & gender2==2
replace gmygcown = 0 if gmygcown==.

lab var gfygcown "couple: youngest grandchild biolog. rel. to grandfather"
lab var gmygcown "couple: youngest grandchild biolog. rel. to grandmother"

* code a dummy for youngest grandchild not of own child
gen gfygcnotown = gfygcown==0
* code a dummy for nearest child with child is in the same household or up to 5 km away
gen shortdist = inlist(mincdist,1,2) 
* only keep relevant variables
keep mergeid? wave* hhid cplage cpllimit cpljobhrs empcf gf* gm* mincdist shortdist mincycage mincycage_class cplisgt* hisced country   
* drop within wave duplicates to return to couple data format
duplicates drop wave mergeid1 mergeid2, force


* care indicator
gen care = 0

* append caring grandparents
append using "${tempDir}/20_variables_imputation"

* care = 1 for caring grandparents
replace care = 1 if care== .

* if couple's weekly hours of caring are zero, recode to not caring 
replace care = 0 if cplsumwkhrs_impmod3 == 0


* generate retirement indicator
gen nonret = empcf < 5
gen ret = empcf==5

* set grandmother's jobshare to missing if couple is inactive/retired
replace gmjobshr = . if ret == 1

* create dummy set for limitations regarding activities of daily living
tab cpllimit, gen(lim_)

* create dummy set for employment configuration in couple
tab empcf, gen(emp_)


**
* Compare of grandparent couples providing care 
* and grandparent couples not providing care
**
fre care
tabstat emp_1-emp_5 ///
		cplage cplisgt3 shortdist mincycage gfygcnotown ///
		lim_1 lim_2 lim_3 lim_4 /// 
		cpljobhrs, by(care) stats(mean) f(%9.2f)
* univariate comparisons
ttest 	emp_1, by(care)
ttest 	emp_2, by(care)
ttest 	emp_3, by(care)
ttest 	emp_4, by(care)
ttest 	emp_5, by(care)
ttest  cplage, by(care)
ttest  cplisgt3, by(care)
ttest  shortdist, by(care)
ttest  mincycage, by(care)
ttest  gfygcnotown, by(care)
ttest  lim_1, by(care)
ttest  lim_2, by(care)
ttest  lim_3, by(care)
ttest  lim_4, by(care)
ttest  cpljobhrs, by(care)

* multivariate selection model (logistic regression)
* estimate the probability of being a "caring" grandparent couple conditional on covariates		
logit care ib1.empcf cplage cplisgt3 shortdist mincycage gfygcnotown lim_2 lim_3 lim_4 cpljobhrs
est store selection
* plot results (show odds ratios of being a "caring" couple)
estout selection, cells(b(fmt(%9.3f) star)) ///
				  stats(N ll r2_p, fmt(%9.3g) labels("Observations" "Log-lik." "Pseudo R-sqr." )) /// 
				  nolz /// 
				  starlevels(* .05 ** .01 *** .001) ///
				  varlabels(_cons "Constant" ///
							cplage "Couple's mean age" ///
							shortdist "Short distance" ///
							cplisgt3 "Post-secondary education" ///
							mincycage "Youngest GC's age" ///
							gfygcnotown "Youngest grandchild not from GF" ///
							cpljobhrs "Couples job hours per week" ///
							lim_2 "Sick/Limit.: only GF" ///
							lim_3 "Sick/Limit.: only GM" ///
							lim_4 "Sick/Limit.: both" ///
							2.empcf "both fulltime working" ///
							3.empcf "GM fulltime working" ///
							4.empcf "working but not fulltime" ///
							5.empcf "both retired/inactive" ///
							) /// 
				  drop(1b.empcf) ///			
				  varwidth(35) ///
				  transform(exp(@)) ///
				  modelwidth(20) ///
				  legend ///
				  mlabels("logit[P(Care)], OR")

* Results: 
* - caring couples are less involved in market work (not working fulltime, inactive/retired)
* - couples with higher mean age are less likely to provide care
* - couples with post-secondary education are more likely to provide care
* - couples with short distance to children are more likely to provide care
* - couples with older (youngest) grandchild are less likely to provide care
* - couples with health limitations are less likely to provide care (in particular, if grandmother has limitations)
* - couples working more hours per week are more likely to provide care 
*   (of course, this is conditional on the employment status; hence, this might be interpreted as more "active" couples are more likely to care)  
